@@ -4,13 +4,7 @@ from .base_atari_env import BaseAtariEnv, base_env_wrapper_fn, parallel_wrapper_
 
 
 def raw_env(**kwargs):
-    return BaseAtariEnv(
-        game="boxing",
-        num_players=2,
-        mode_num=None,
-        env_name=os.path.basename(__file__)[:-3],
-        **kwargs
-    )
+    return BaseAtariEnv(game="boxing", num_players=2, mode_num=None, env_name=os.path.basename(__file__)[:-3], **kwargs)
 
 
 env = base_env_wrapper_fn(raw_env)
