@@ -10,24 +10,23 @@ from pettingzoo.utils import wrappers
 from pettingzoo.utils.agent_selector import agent_selector
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
-from .cake_paddle import RENDER_RATIO, CakePaddle
-from .manual_control import manual_control
+from .ball import Ball
+from .cake_paddle import CakePaddle
+from .paddle import Paddle
 
-os.environ['PYGAME_HIDE_SUPPORT_PROMPT'] = 'hide'
-
-KERNEL_WINDOW_LENGTH = 2
+FPS = 15
 
 
 def deg_to_rad(deg):
     return deg * np.pi / 180
 
 
-def get_flat_shape(width, height):
-    return int(width * height / (KERNEL_WINDOW_LENGTH * KERNEL_WINDOW_LENGTH))
+def get_flat_shape(width, height, kernel_window_length=2):
+    return int(width * height / (kernel_window_length * kernel_window_length))
 
 
-def original_obs_shape(screen_width, screen_height):
-    return (int(screen_height * 2 / KERNEL_WINDOW_LENGTH), int(screen_width * 2 / (KERNEL_WINDOW_LENGTH)), 1)
+def original_obs_shape(screen_width, screen_height, kernel_window_length=2):
+    return (int(screen_height * 2 / kernel_window_length), int(screen_width * 2 / (kernel_window_length)), 1)
 
 
 def get_valid_angle(randomizer):
@@ -52,157 +51,18 @@ def get_valid_angle(randomizer):
     return angle
 
 
-def get_small_random_value(randomizer):
-    # generates a small random value between [0, 1/100)
-    return (1 / 100) * randomizer.rand()
-
-
-class PaddleSprite(pygame.sprite.Sprite):
-    def __init__(self, dims, speed):
-        self.surf = pygame.Surface(dims)
-        self.rect = self.surf.get_rect()
-        self.speed = speed
-
-    def reset(self):
-        pass
-
-    def draw(self, screen):
-        pygame.draw.rect(screen, (255, 255, 255), self.rect)
-
-    def update(self, area, action):
-        # action: 1 - up, 2 - down
-        movepos = [0, 0]
-        if action > 0:
-            if action == 1:
-                movepos[1] = movepos[1] - self.speed
-            elif action == 2:
-                movepos[1] = movepos[1] + self.speed
-
-            # make sure the players stay inside the screen
-            newpos = self.rect.move(movepos)
-            if area.contains(newpos):
-                self.rect = newpos
-
-    def process_collision(self, b_rect, dx, dy, b_speed, paddle_type):
-        '''
-
-        Parameters
-        ----------
-        b_rect : Ball rect
-        dx, dy : Ball speed along single axis
-        b_speed : Ball speed
-
-        Returns
-        -------
-        is_collision: 1 if ball collides with paddle
-        b_rect: new ball rect
-        b_speed: new ball speed
-
-        '''
-        if paddle_type == 1:
-            if self.rect.colliderect(b_rect):
-                is_collision = True
-                if dx < 0:
-                    b_rect.left = self.rect.right
-                    b_speed[0] = -b_speed[0]
-                # top or bottom edge
-                elif dy > 0:
-                    b_rect.bottom = self.rect.top
-                    b_speed[1] = -b_speed[1]
-                elif dy < 0:
-                    b_rect.top = self.rect.bottom
-                    b_speed[1] = -b_speed[1]
-                return is_collision, b_rect, b_speed
-        elif paddle_type == 2:
-            if self.rect.colliderect(b_rect):
-                is_collision = True
-                if dx > 0:
-                    b_rect.right = self.rect.left
-                    b_speed[0] = -b_speed[0]
-                # top or bottom edge
-                elif dy > 0:
-                    b_rect.bottom = self.rect.top
-                    b_speed[1] = -b_speed[1]
-                elif dy < 0:
-                    b_rect.top = self.rect.bottom
-                    b_speed[1] = -b_speed[1]
-                return is_collision, b_rect, b_speed
-        return False, b_rect, b_speed
-
-
-class BallSprite(pygame.sprite.Sprite):
-    def __init__(self, randomizer, dims, speed, bounce_randomness=False):
-        self.surf = pygame.Surface(dims)
-        self.rect = self.surf.get_rect()
-        self.speed_val = speed
-        self.speed = [int(self.speed_val * np.cos(np.pi / 4)), int(self.speed_val * np.sin(np.pi / 4))]
-        self.bounce_randomness = bounce_randomness
-        self.done = False
-        self.hit = False
-        self.randomizer = randomizer
-
-    def update2(self, area, p0, p1):
-        (speed_x, speed_y) = self.speed
-        done_x, done_y = False, False
-        if self.speed[0] != 0:
-            done_x = self.move_single_axis(self.speed[0], 0, area, p0, p1)
-        if self.speed[1] != 0:
-            done_y = self.move_single_axis(0, self.speed[1], area, p0, p1)
-        return (done_x or done_y)
-
-    def move_single_axis(self, dx, dy, area, p0, p1):
-        # move ball rect
-        self.rect.x += dx
-        self.rect.y += dy
-
-        if not area.contains(self.rect):
-            # bottom wall
-            if dy > 0:
-                self.rect.bottom = area.bottom
-                self.speed[1] = -self.speed[1]
-            # top wall
-            elif dy < 0:
-                self.rect.top = area.top
-                self.speed[1] = -self.speed[1]
-            # right or left walls
-            else:
-                return True
-                self.speed[0] = -self.speed[0]
-
-        else:
-            # Do ball and bat collide?
-            # add some randomness
-            r_val = 0
-            if self.bounce_randomness:
-                r_val = get_small_random_value(self.randomizer)
-
-            # ball in left half of screen
-            if self.rect.center[0] < area.center[0]:
-                is_collision, self.rect, self.speed = p0.process_collision(self.rect, dx, dy, self.speed, 1)
-                if is_collision:
-                    self.speed = [self.speed[0] + np.sign(self.speed[0]) * r_val, self.speed[1] + np.sign(self.speed[1]) * r_val]
-            # ball in right half
-            else:
-                is_collision, self.rect, self.speed = p1.process_collision(self.rect, dx, dy, self.speed, 2)
-                if is_collision:
-                    self.speed = [self.speed[0] + np.sign(self.speed[0]) * r_val, self.speed[1] + np.sign(self.speed[1]) * r_val]
-
-        return False
-
-    def draw(self, screen):
-        # screen.blit(self.surf, self.rect)
-        pygame.draw.rect(screen, (255, 255, 255), self.rect)
-
-
 class CooperativePong:
-    def __init__(self, randomizer, ball_speed=9, left_paddle_speed=12, right_paddle_speed=12, cake_paddle=True, max_cycles=900, bounce_randomness=False, max_reward=100, off_screen_penalty=-10):
+    def __init__(self, randomizer, ball_speed=9, left_paddle_speed=12, right_paddle_speed=12, cake_paddle=True, max_cycles=900, bounce_randomness=False, max_reward=100, off_screen_penalty=-10, render_ratio=2, kernel_window_length=2):
         super().__init__()
 
         pygame.init()
         self.num_agents = 2
 
+        self.render_ratio = render_ratio
+        self.kernel_window_length = kernel_window_length
+
         # Display screen
-        self.s_width, self.s_height = 960 // RENDER_RATIO, 560 // RENDER_RATIO
+        self.s_width, self.s_height = 960 // render_ratio, 560 // render_ratio
         self.screen = pygame.Surface((self.s_width, self.s_height))  # (960, 720) # (640, 480) # (100, 200)
         self.area = self.screen.get_rect()
         self.max_reward = max_reward
@@ -210,7 +70,7 @@ class CooperativePong:
 
         # define action and observation spaces
         self.action_space = [gym.spaces.Discrete(3) for _ in range(self.num_agents)]
-        original_shape = original_obs_shape(self.s_width, self.s_height)
+        original_shape = original_obs_shape(self.s_width, self.s_height, kernel_window_length=kernel_window_length)
         original_color_shape = (original_shape[0], original_shape[1], 3)
         self.observation_space = [gym.spaces.Box(low=0, high=255, shape=(original_color_shape), dtype=np.uint8) for _ in range(self.num_agents)]
         # define the global space of the environment or state
@@ -224,16 +84,16 @@ class CooperativePong:
         self.max_cycles = max_cycles
 
         # paddles
-        self.p0 = PaddleSprite((20 // RENDER_RATIO, 80 // RENDER_RATIO), left_paddle_speed)
+        self.p0 = Paddle((20 // render_ratio, 80 // render_ratio), left_paddle_speed)
         if cake_paddle:
-            self.p1 = CakePaddle(right_paddle_speed)
+            self.p1 = CakePaddle(right_paddle_speed, render_ratio=render_ratio)
         else:
-            self.p1 = PaddleSprite((20 // RENDER_RATIO, 100 // RENDER_RATIO), right_paddle_speed)
+            self.p1 = Paddle((20 // render_ratio, 100 // render_ratio), right_paddle_speed)
 
         self.agents = ["paddle_0", "paddle_1"]  # list(range(self.num_agents))
 
         # ball
-        self.ball = BallSprite(randomizer, (20 // RENDER_RATIO, 20 // RENDER_RATIO), ball_speed, bounce_randomness)
+        self.ball = Ball(randomizer, (20 // render_ratio, 20 // render_ratio), ball_speed, bounce_randomness)
         self.randomizer = randomizer
 
         self.reinit()
@@ -319,7 +179,7 @@ class CooperativePong:
             self.rewards = {a: 0 for a in self.agents}
             self.p0.update(self.area, action)
         elif agent == self.agents[1]:
-            self.p1.update(self.area, action, self.ball.rect)
+            self.p1.update(self.area, action)
 
             # do the rest if not done
             if not self.done:
@@ -362,7 +222,12 @@ parallel_env = parallel_wrapper_fn(env)
 
 class raw_env(AECEnv, EzPickle):
     # class env(MultiAgentEnv):
-    metadata = {'render.modes': ['human', "rgb_array"], 'name': "cooperative_pong_v4"}
+    metadata = {
+        'render.modes': ['human', "rgb_array"],
+        'name': "cooperative_pong_v5",
+        'is_parallelizable': True,
+        'video.frames_per_second': FPS
+    }
 
     def __init__(self, **kwargs):
         EzPickle.__init__(self, **kwargs)
