@@ -12,6 +12,7 @@ from pettingzoo.utils import agent_selector, wrappers
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
 from .manual_control import manual_control
+from .manual_policy import ManualPolicy
 from .src import constants as const
 from .src.img import get_image
 from .src.players import Archer, Knight
@@ -35,7 +36,7 @@ class raw_env(AECEnv, EzPickle):
 
     metadata = {
         "render.modes": ["human", "rgb_array"],
-        "name": "knights_archers_zombies_v8",
+        "name": "knights_archers_zombies_v9",
         "is_parallelizable": True,
         "video.frames_per_second": const.FPS,
     }
@@ -121,7 +122,7 @@ class raw_env(AECEnv, EzPickle):
 
         # Initializing Pygame
         pygame.init()
-         # self.WINDOW = pygame.display.set_mode([self.WIDTH, self.HEIGHT])
+        # self.WINDOW = pygame.display.set_mode([self.WIDTH, self.HEIGHT])
         self.WINDOW = pygame.Surface((const.SCREEN_WIDTH, const.SCREEN_HEIGHT))
         pygame.display.set_caption("Knights, Archers, Zombies")
         self.left_wall = get_image(os.path.join("img", "left_wall.png"))
@@ -309,6 +310,10 @@ class raw_env(AECEnv, EzPickle):
         # agent: agent instance
         agent = self.agent_list[self.agent_name_mapping[self.agent_selection]]
 
+        # cumulative rewards from previous iterations should be cleared
+        self._cumulative_rewards[self.agent_selection] = 0
+        agent.score = 0
+
         # this is... so whacky... but all actions here are index with 1 so... ok
         action = action + 1
         out_of_bounds = agent.update(action)
@@ -364,32 +369,35 @@ class raw_env(AECEnv, EzPickle):
             self.check_game_end()
             self.frames += 1
 
-        self._clear_rewards()
-        self.rewards[self.agent_selection] = agent.score
-        agent.score = 0
         done = not self.run or self.frames >= self.max_cycles
-        self.dones = {a: done for a in self.possible_agents}
+        self.dones = {a: done for a in self.agents}
 
         # manage the kill list
         if self._agent_selector.is_last():
+            # start iterating on only the living agents
+            _live_agents = self.agents[:]
             for k in self.kill_list:
-                self.agents.remove(k)
-                self.dead_agents.append(k)
-
-            for k in self.dead_agents:
+                # kill the agent
+                _live_agents.remove(k)
+                # set the done for this agent for one round
                 self.dones[k] = True
+                # add that we know this guy is dead
+                self.dead_agents.append(k)
 
             # reset the kill list
             self.kill_list = []
 
             # reinit the agent selector with existing agents
-            self._agent_selector.reinit(self.agents)
+            self._agent_selector.reinit(_live_agents)
 
         # if there still exist agents, get the next one
         if len(self._agent_selector.agent_order):
             self.agent_selection = self._agent_selector.next()
 
-        self._cumulative_rewards[agent.agent_name] = 0
+        self._clear_rewards()
+        next_agent = self.agent_list[self.agent_name_mapping[self.agent_selection]]
+        self.rewards[self.agent_selection] = next_agent.score
+
         self._accumulate_rewards()
         self._dones_step_first()
 
