@@ -14,6 +14,7 @@ from .manual_control import manual_control
 FPS = 15
 PRISONER_VELOCITY = 24
 
+
 def get_image(path):
     from os import path as os_path
     cwd = os_path.dirname(__file__)
@@ -101,7 +102,7 @@ class raw_env(AECEnv, EzPickle):
         self.sprite_img_heights = [40, 40, 46, 48, 32, 54, 48, 53]
         self.metadata = {
             'render.modes': ['human', "rgb_array"],
-            'name': "prison_v3",
+            'name': "prison_v4",
             'is_parallelizable': True,
             'video.frames_per_second': FPS,
         }
@@ -148,7 +149,7 @@ class raw_env(AECEnv, EzPickle):
                 self.observation_spaces[a] = spaces.Box(low=-300, high=300, shape=(1,), dtype=np.float32)
             else:
                 self.observation_spaces[a] = spaces.Box(low=0, high=255, shape=(100, 300, 3), dtype=np.uint8)
-        self.state_space = spaces.Box(low=0, high=255, shape=(650, 750, 3), dtype=np.uint8)
+        self.state_space = spaces.Box(low=0, high=255, shape=(50 + 150 * self.num_floors, 750, 3), dtype=np.uint8)
 
         self.walls = []
         self.create_walls(num_floors)
