@@ -7,7 +7,6 @@ from gym.spaces import Box, Discrete
 from gym.utils import EzPickle
 
 from pettingzoo import AECEnv
-from pettingzoo.magent.render import Renderer
 from pettingzoo.utils import agent_selector
 from pettingzoo.utils.conversions import parallel_to_aec_wrapper, parallel_wrapper_fn
 
@@ -149,7 +148,7 @@ class _parallel_env(magent_parallel_env, EzPickle):
         "render.modes": ["human", "rgb_array"],
         'name': "combined_arms_v5",
         "video.frames_per_second": 5,
-        }
+    }
 
     def __init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features):
         EzPickle.__init__(self, map_size, minimap_mode, reward_args, max_cycles, extra_features)
