@@ -1,13 +1,12 @@
 import math
 import warnings
 
-import magent
 import numpy as np
 from gym.spaces import Box, Discrete
 from gym.utils import seeding
+from magent import Renderer
 
 from pettingzoo import AECEnv
-from pettingzoo.magent.render import Renderer
 from pettingzoo.utils import agent_selector, wrappers
 from pettingzoo.utils.env import ParallelEnv
 
@@ -51,7 +50,7 @@ class magent_parallel_env(ParallelEnv):
                 idx = space.shape[2] - 3 if minimap_mode else space.shape[2] - 1
                 space.low[:, :, idx] = reward_low
                 space.high[:, :, idx] = reward_high
-            idx_state = self.state_space.shape[2] - 3 if minimap_mode else self.state_space.shape[2] - 1
+            idx_state = self.state_space.shape[2] - 1 if minimap_mode else self.state_space.shape[2] - 1
             self.state_space.low[:, :, idx_state] = reward_low
             self.state_space.high[:, :, idx_state] = reward_high
 
