@@ -25,7 +25,11 @@ class SimpleEnv(AECEnv):
 
         self.seed()
 
-        self.metadata = {'render.modes': ['human', 'rgb_array']}
+        self.metadata = {
+            'render.modes': ['human', 'rgb_array'],
+            'is_parallelizable': True,
+            'video.frames_per_second': 10
+        }
 
         self.max_cycles = max_cycles
         self.scenario = scenario
