@@ -5,6 +5,7 @@ from pettingzoo import AECEnv
 from pettingzoo.utils import agent_selector, wrappers
 from pettingzoo.utils.conversions import parallel_wrapper_fn
 
+from .multiwalker_base import FPS
 from .multiwalker_base import MultiWalkerEnv as _env
 
 
@@ -20,7 +21,12 @@ parallel_env = parallel_wrapper_fn(env)
 
 class raw_env(AECEnv, EzPickle):
 
-    metadata = {'render.modes': ['human', "rgb_array"], 'name': 'multiwalker_v7'}
+    metadata = {
+        'render.modes': ['human', "rgb_array"],
+        'name': 'multiwalker_v8',
+        'is_parallelizable': True,
+        'video.frames_per_second': FPS,
+    }
 
     def __init__(self, *args, **kwargs):
         EzPickle.__init__(self, *args, **kwargs)
